
#
# Drag and Drop implements a set of variables, actually global, which define
# the dragged element and the dropped element. The main interest is the type
# of the oject, since it defines the set of operations which can take place
# on the object. In addition their is the Track, which refers to a track if
# we are a SLabTrack type, or bus if we are a SLabBus. The Frame parameters
# are really for internal use (perhaps remove this definition from the user
# code section?), it defines an internal frame identification. The ObjectIDs
# are actually a file reference from the MixSLab user interface. This file
# name can be passed as a parameter to an external programme. The filename
# is used internally, for example, as the name of the effect we are going to
# start when dragging and EffectsTool to a bus, or the name of a DiskFile we
# are going to mix.
#
# This process is called before any of the default bindings.
# If you want to terminate processing of a DragAndDrop event, because you
# do not like a default binding, return a value of "done". If you want to 
# continue processing, you can also change any of the defined variables to 
# alter the default processing sequences.
#

proc userDragAndDropInit {} {
	# To add a tool to the user interface, use the command
	#
	#	addMixSLabButton ToolName Command fgColor bgColor
	#
	# addMixSLabButton seaches the bitmaps directory, firstly looking for
	# ToolName.ppm, failing that for ToolName.bitmap and ToolNameMask.bitmap,
	# and failing that, just uses text in the button. You can use the defined
	# callback command in this file, and this will be requested with a single
	# parameter which is the ToolName, which can be used for demultiplexing.
	# The Command is invoked when the button is pushed.
	# If you use a PPM file as the button image, you should still create
	# the ToolName.bitmap and Mask file, since these will be used for the
	# pointer when this tool is dragged onto something else. If you do not 
	# define the bitmaps, a default pointer will be used to signify the tool
	# is being dragged.
	#
	# addMixSLabButton TestSLab userMixSLabButtonCommand black slategrey
}

#
# If your new tools, ToolName is dragged to another tool, this procedure is
# invoked:
#
proc userDragAndDropLinks {} {
	global dragTrack dragFrame dragObjectType dragObjectID dragCommand
	global dropTrack dropFrame dropObjectType dropObjectID dropCommand

	switch $dragObjectType {
		"SLabDiskFile" {
			switch $dropObjectType {
				"TestSLabCreator" {
					#
					# At this point a device of "ToolName" has been dragged to
					# track on the mixing desk.
					#
					# $dropTrack refers to the track on which ToolName was
					# dropped.
					puts "SLabDiskFile to TestSLabCreator"
					return done
				}
			}
		}
		"TestSLabCreator" {
			switch $dropObjectType {
				"SLabDiskFile" {
					#
					# At this point a device of "Track" has been dragged to
					# your new object in the MixSLab.
					#
					# $dropTrack refers to the track which was dropped.
					puts "TestSLabCreator to SLabDiskFile"
					return done
				}
			}
		}
	}
	return continue
}

proc userMixSLabButtonCommand { toolName } {
	switch $toolName {
		"TestSLab" {
			#
			# Insert your code here.
			#
		}
	}
}

